@@ -4,6 +4,12 @@ from sqlalchemy.exc import IntegrityError
 
 from compstack.sqlalchemy import db
 
+def sa_dialect_is(*testfor):
+    for d in testfor:
+        if db.engine.dialect.name == d:
+            return True
+    return False
+
 def is_unique_exc(exc):
     if isinstance(exc, ValidationError):
         return len(exc.invalid_instances) == 1 and _is_unique_error_saval(exc.invalid_instances[0].validation_errors)
@@ -80,7 +86,6 @@ def _is_fk_msg(dialect, msg, key_cname, ref_cname):
         # postgresql does not have the field name in the message when the
         # record referenced by a FK is deleted, so don't check for field_name
         # here
-        print 'here', msg
         if 'violates foreign key constraint' in msg:
             if msg.startswith('insert or update') and ('Key (%s)=' % key_cname) in msg:
                 return True
@@ -101,6 +106,10 @@ def _is_fk_msg(dialect, msg, key_cname, ref_cname):
     return False
 
 def is_null_exc(exc, field_name):
+    if isinstance(exc, ValidationError):
+        if len(exc.invalid_instances) != 1:
+            return False
+        return _is_null_error_saval(exc.invalid_instances[0].validation_errors, field_name)
     if not isinstance(exc, IntegrityError):
         return False
     return _is_null_msg(db.engine.dialect.name, str(exc), field_name)
@@ -122,6 +131,36 @@ def _is_null_msg(dialect, msg, field_name):
         raise ValueError('is_null_exc() does not yet support dialect: %s' % dialect)
     return False
 
+def _is_null_error_saval(validation_errors, field_name):
+    if not len(validation_errors):
+        return False
+    for field, error_msgs in validation_errors.items():
+        if field != field_name:
+            return False
+        for err in tolist(error_msgs):
+            if 'Please enter a value' != err:
+                return False
+    return True
+
+def is_check_const_exc(exc, constraint_name):
+    if not isinstance(exc, IntegrityError):
+        return False
+    return _is_check_const(db.engine.dialect.name, str(exc), constraint_name)
+
+def _is_check_const(dialect, msg, constraint_name):
+    if dialect == 'mssql':
+        if 'conflicted with the CHECK constraint' in msg and constraint_name in msg:
+            return True
+    elif dialect == 'sqlite':
+        if 'constraint failed' in msg:
+            return True
+    elif dialect == 'postgresql':
+        if 'violates check constraint' in msg and constraint_name in msg:
+            return True
+    else:
+        raise ValueError('is_constraint_exc() does not yet support dialect: %s' % dialect)
+    return False
+
 def clear_db():
     if db.engine.dialect.name == 'postgresql':
         sql = []
