@@ -6,5 +6,5 @@ class TestPostgres(Test):
         # call parent init to setup default settings
         Test.init(self)
         self.db.url = 'postgresql://postgres:postgres@rcsserver/test'
-        self.db.echo = True
+        #self.db.echo = True
 testpgsql = TestPostgres
